C++ Umgebungs-Setup
Wenn Sie eine C++-Sprachumgebung einrichten möchten, müssen Sie sicherstellen, dass die folgenden zwei Softwareprogramme auf Ihrem Computer verfügbar sind: ein Texteditor und ein C++-Compiler.
Texteditor
Dateien, die durch einen Editor erstellt werden, werden üblicherweise als Quelldateien bezeichnet, und Quelldateien enthalten den Quellcode des Programms.
Quelldateien für C++-Programme verwenden normalerweise die Erweiterung.cpp、.cpoder.c。
Bevor Sie mit dem Programmieren beginnen, stellen Sie sicher, dass Sie einen Texteditor und genügend Erfahrung haben, um ein Computerprogramm zu schreiben, speichern Sie es dann in einer Datei, kompilieren Sie es und führen Sie es aus.
Visual Studio Code: Obwohl es sich um einen Allzweck-Texteditor handelt, bietet es viele Plugins, die die C/C++-Entwicklung unterstützen, was es zu einer beliebten Wahl macht. Durch die Installation von C/C++-Plugins und die Anpassung der Einstellungen können Sie es in eine großartige C-Entwicklungsumgebung verwandeln.
Installationsanleitung:https://www.example.com/w3cnote/vscode-tutorial.html
Download-URL:https://code.visualstudio.com/
Visual Studio: Eine umfassende Windows-IDE für .NET- und C++-Entwickler, die zum Erstellen von Web-, Cloud-, Desktop-, Mobil-Apps, Diensten und Spielen verwendet werden kann.
Download-URL:https://visualstudio.microsoft.com/zh-hans/downloads/。
VimundEmacs: Dies sind zwei traditionelle Texteditoren. Sie verfügen über leistungsstarke Bearbeitungsfunktionen und ein hohes Maß an Anpassbarkeit. Sie sind sehr leistungsstark für erfahrene Benutzer, und es gibt viele Plugins und Konfigurationen, die die C-Entwicklung unterstützen können.
Eclipse: Eclipse ist eine weitere leistungsstarke integrierte Entwicklungsumgebung. Obwohl sie ursprünglich für die Java-Entwicklung entwickelt wurde, kann sie die C-Entwicklung durch die Installation von C/C++-Plugins unterstützen.
Weitere verwandte Tools
C++-Compiler
Der in einer Quelldatei geschriebene Quellcode ist für Menschen lesbarer Quellcode. Er muss in Maschinensprache "kompiliert" werden, damit die CPU das Programm gemäß den gegebenen Anweisungen ausführen kann.
Der C++-Compiler wird verwendet, um Quellcode in ein endgültiges ausführbares Programm zu kompilieren.
Die meisten C++-Compiler kümmern sich nicht um die Dateiendung der Quelldatei, aber wenn Sie keine Endung angeben, wird standardmäßig.cpp verwendet.。
Der am häufigsten verwendete frei verfügbare Compiler ist der GNU C/C++-Compiler. Wenn Sie HP oder Solaris verwenden, können Sie den Compiler unter Ihrem jeweiligen Betriebssystem verwenden.
Die folgenden Abschnitte zeigen Ihnen, wie Sie den GNU C/C++-Compiler unter verschiedenen Betriebssystemen installieren. C/C++ wird hier hauptsächlich gemeinsam erwähnt, weil der GNU-gcc-Compiler sowohl für die Programmiersprachen C als auch C++ geeignet ist.
Installation unter UNIX/Linux
Wenn SieLinux oder UNIXverwenden, verwenden Sie bitte den folgenden Befehl in der Kommandozeile, um zu prüfen, ob GCC auf Ihrem System installiert ist:
$ g++ -v
Wenn der GNU-Compiler bereits auf Ihrem Computer installiert ist, wird eine Meldung wie die folgende angezeigt:
Using built-in specs. Target: i386-redhat-linux Configured with: ../configure --prefix=/usr ....... Thread model: posix gcc version 4.1.2 20080704 (Red Hat 4.1.2-46)
Wenn GCC nicht installiert ist, dann folgen Sie bitte den Anweisungen inhttps://gcc.gnu.org/install/Detaillierte Anweisungen zur Installation von GCC unter
Installation unter Mac OS X
Wenn Sie Mac OS X verwenden, erhalten Sie GCC am schnellsten, indem Sie die Xcode-Entwicklungsumgebung von der Apple-Website herunterladen und gemäß den Installationsanweisungen installieren. Sobald Xcode installiert ist, können Sie den GNU-Compiler verwenden.
Xcode ist derzeit verfügbar unterhttps://developer.apple.com/downloadZum Herunterladen ist eine Anmeldung mit Apple ID erforderlich.
Installation unter Windows
Cygwin
Cygwin ist ein Softwarepaket, das eine Unix-/Linux-Umgebung auf dem Windows-Betriebssystem emuliert und es Benutzern ermöglicht, Unix-ähnliche Werkzeuge und Anwendungen unter Windows zu verwenden.
Cygwin bietet eine Reihe von DLLs (Dynamic Link Libraries), die als Brücke zwischen der Unix-Systemaufrufebene und dem Windows-Kernel fungieren und es Unix-Programmen ermöglichen, auf Windows-Systemen ausgeführt zu werden.
Offizielle Cygwin-Website: https://www.cygwin.com/。
Laden Sie das Installationsprogramm von der offiziellen Website herunter:

Doppelklicken Sie nach dem Herunterladen auf die heruntergeladene Datei:
Als Nächstes können Sie weiterhin auf Weiter klicken:
Here we can add the NetEase open-source mirror and Alibaba Cloud mirrorhttps://mirrors.aliyun.com/cygwin/:

Nach Abschluss der Installation wird ein Symbol auf dem Desktop erstellt:

Double-click the icon to enter the command line interface and entercygcheck -c cygwinein. Mit dem Befehl können Sie die aktuellen Cygwin-Versionsinformationen anzeigen:

Als Nächstes installieren wir die gcc/g++-Kompilierungsumgebung. Wechseln Sie in der Befehlszeile in das Verzeichnis von setup-x86_64.exe und führen Sie aus:
setup-x86_64.exe -q -P wget -P gcc-g++ -P make -P diffutils -P libmpfr-devel -P libgmp-devel -P libmpc-devel
Nach Abschluss der Installation öffnen Sie das Cygwin64-Terminal und geben Siegcc --version ein.Mit diesem Befehl können Sie die Versionsinformationen anzeigen.
MinGW-w64
Um GCC unter Windows zu installieren, müssen Sie MinGW-w64 installieren.
MinGW-w64 ist ein Open-Source-Projekt, das eine vollständige GCC-Toolchain für Windows-Systeme bereitstellt und die Kompilierung von 32-Bit- und 64-Bit-Windows-Anwendungen unterstützt.
Besuchen Sie die MinGW-w64-Homepagemingw-w64.orgGehen Sie zur MinGW-Downloadseitehttps://www.mingw-w64.org/downloads/Laden Sie die neueste Version des MinGW-w64-Installers herunter.
Sie können es auch von Github herunterladen:https://github.com/niXman/mingw-builds-binaries/releases
Die MinGW-w64-Download-Detailseite enthält viele integrierte Pakete von MinGW-w64 und spezifische Tools:

Wir installieren nur MinGW-w64, daher müssen Sie nur MinGW-w64 herunterladen. Klicken Sie auf den Hyperlink "SourceForge" im roten Kasten, um zur MinGW-w64-Downloadseite auf SourceForge zu gelangen.
Laden Sie MinGW-w64 von SourceForge herunter:https://sourceforge.net/projects/mingw-w64/files/

Scrollen Sie auf der Seite nach unten und laden Sie den Installer herunter:

Bei dieser Art der Installation können Netzwerkverbindungsfehler auftreten, daher können wir direkt sjlj herunterladen (stabil, unterstützt sowohl 64-Bit als auch 32-Bit):

Nach dem Herunterladen entpacken Sie es, und Sie finden g++.exe oder gcc.exe im bin-Verzeichnis:

Bei der Installation von MinGW sollten Sie mindestens gcc-core, gcc-g++, binutils und MinGW runtime installieren, aber im Allgemeinen werden mehr andere Elemente installiert.
Add the bin subdirectory of your installed MinGW to yourPATHin den Umgebungsvariablen hinzu, auf diese Weise können Sie diese Tools mit einfachen Namen in der Befehlszeile angeben.

Wenn die Installation abgeschlossen ist, können Sie gcc, g++, ar, ranlib, dlltool und andere GNU-Tools von der Windows-Befehlszeile aus ausführen.
Kompilieren mit Visual Studio (grafische Oberfläche)
1. Download and installationVisual Studio Download。

2. Öffnen Sie Visual Studio Community
3. Klicken Sie auf File -> New -> Project
4. Wählen Sie in der linken Liste Templates -> Visual C++ -> Win32 Console Application aus und legen Sie den Projektnamen auf MyFirstProgram fest.

5. Klicken Sie auf OK.
6. Klicken Sie im folgenden Fenster auf Next
7. Wählen Sie im Pop-up-Fenster die Option Empty project aus und klicken Sie dann auf die Schaltfläche Finish:
8. Klicken Sie mit der rechten Maustaste auf den Ordner Source File und dann auf Add --> New Item...:
9. Wählen Sie C++ File, legen Sie den Dateinamen auf main.cpp fest und klicken Sie dann auf Add:

10. Kopieren Sie den folgenden Code in main.cpp:
#include <iostream>
int main()
{
std::cout << "Hello World!\n";
return 0;
}
Die Benutzeroberfläche ist wie unten dargestellt:

11. Klicken Sie im Menü auf Debug -> Start Without Debugging (oder drücken Sie Ctrl+F5):

12. Nach Abschluss der oben genannten Vorgänge sehen Sie die folgende Ausgabe:

g++-Anwendungshinweise
Das Programm g++ ist eine spezielle Version von gcc, die die Standardsprache auf C++ festlegt. Beim Linken verwendet es automatisch die C++-Standardbibliothek anstelle der C-Standardbibliothek. Wenn man die Namenskonventionen für den Quellcode befolgt und die entsprechenden Bibliotheksnamen angibt, ist es möglich, C++-Programme mit gcc zu kompilieren und zu linken, wie im folgenden Beispiel gezeigt:
$ gcc main.cpp -lstdc++ -o main
Unten sehen Sie den Code eines einfachen C++-Programms, das in der Datei helloworld.cpp gespeichert ist:
#include <iostream>
using namespace std;
int main()
{
cout << "Hello, world!" << endl;
return 0;
}
Die einfachste Art zu kompilieren:
$ g++ helloworld.cpp
Da der Name der ausführbaren Datei nicht in der Befehlszeile angegeben wurde, verwendet der Compiler standardmäßig a.out. Das Programm kann wie folgt ausgeführt werden:
$ ./a.out Hello, world!
Normalerweise verwenden wir-oDie Option gibt den Namen der ausführbaren Datei an. Das folgende Beispiel erzeugt eine ausführbare Datei namens helloworld:
$ g++ helloworld.cpp -o helloworld
helloworld ausführen:
$ ./helloworld Hello, world!
Wenn mehrere C++-Codedateien vorhanden sind, wie example1.cpp und example2.cpp, lautet der Kompilierungsbefehl wie folgt:
$ g++ example1.cpp example2.cpp -o example
Eine ausführbare Datei example erzeugen.
Bei manchen Systemen ist für g++ standardmäßig C++98 voreingestellt, und wir können C++11 angeben, um die Datei main.cpp zu kompilieren:
g++ -g -Wall -std=c++11 main.cpp
Häufige g++-Befehlszeilenoptionen
| Optionen | Erklärung |
|---|---|
| -ansi | Unterstützt nur C-Syntax, die dem ANSI-Standard entspricht. Diese Option deaktiviert bestimmte Funktionen von GNU C, wie die Schlüsselwörter asm oder typeof. |
| -c | Nur kompilieren und Objektdateien erzeugen. |
| -DMACRO | Definiert das Makro MACRO als die Zeichenkette "1". |
| -DMACRO=DEFN | Definiert das Makro MACRO mit der Zeichenkette "DEFN". |
| -E | Nur den C-Präprozessor ausführen. |
| -g | Debugging-Informationen erzeugen. Der GNU-Debugger kann diese Informationen verwenden. |
| -IDIRECTORY | Zusätzlichen Suchpfad DIRECTORY für Header-Dateien angeben. |
| -LDIRECTORY | Zusätzlichen Suchpfad DIRECTORY für Bibliotheken angeben. |
| -lLIBRARY | Beim Linken die angegebene Bibliothek LIBRARY suchen. |
| -m486 | Code für 486 optimieren. |
| -o | FILE erzeugt die angegebene Ausgabedatei. Wird beim Erzeugen ausführbarer Dateien verwendet. |
| -O0 | Keine Optimierung durchführen. |
| -O | Oder -O1, um den generierten Code zu optimieren. |
| -O2 | Weitere Optimierung. |
| -O3 | Weitere Optimierung über -O2 hinaus, einschließlich Inline-Funktionen. |
| -shared | Erzeugt eine Shared-Object-Datei. Wird normalerweise beim Erstellen von Shared Libraries verwendet. |
| -static | Deaktiviert die dynamische Verknüpfung. |
| -UMACRO | Hebt die Definition des Makros MACRO auf. |
| -w | Keine Warnmeldungen generieren. |
| -Wall | Alle Warnmeldungen generieren. |